# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/topology.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/topology.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import sequencing_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__parameters__pb2
from . import synchronizer_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_synchronizer__parameters__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3com/digitalasset/canton/protocol/v30/topology.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a@com/digitalasset/canton/protocol/v30/sequencing_parameters.proto\x1a\x42\x63om/digitalasset/canton/protocol/v30/synchronizer_parameters.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\n\n\x05\x45nums\"y\n\x10TopologyChangeOp\x12\"\n\x1eTOPOLOGY_CHANGE_OP_UNSPECIFIED\x10\x00\x12\"\n\x1eTOPOLOGY_CHANGE_OP_ADD_REPLACE\x10\x01\x12\x1d\n\x19TOPOLOGY_CHANGE_OP_REMOVE\x10\x02\"\xb7\x01\n\x15ParticipantPermission\x12&\n\"PARTICIPANT_PERMISSION_UNSPECIFIED\x10\x00\x12%\n!PARTICIPANT_PERMISSION_SUBMISSION\x10\x01\x12\'\n#PARTICIPANT_PERMISSION_CONFIRMATION\x10\x02\x12&\n\"PARTICIPANT_PERMISSION_OBSERVATION\x10\x03\"\xff\x06\n\x13TopologyMappingCode\x12%\n!TOPOLOGY_MAPPING_CODE_UNSPECIFIED\x10\x00\x12.\n*TOPOLOGY_MAPPING_CODE_NAMESPACE_DELEGATION\x10\x01\x12<\n8TOPOLOGY_MAPPING_CODE_DECENTRALIZED_NAMESPACE_DEFINITION\x10\x03\x12.\n*TOPOLOGY_MAPPING_CODE_OWNER_TO_KEY_MAPPING\x10\x04\x12\x38\n4TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_TRUST_CERTIFICATE\x10\x05\x12\x30\n,TOPOLOGY_MAPPING_CODE_PARTICIPANT_PERMISSION\x10\x06\x12.\n*TOPOLOGY_MAPPING_CODE_PARTY_HOSTING_LIMITS\x10\x07\x12)\n%TOPOLOGY_MAPPING_CODE_VETTED_PACKAGES\x10\x08\x12.\n*TOPOLOGY_MAPPING_CODE_PARTY_TO_PARTICIPANT\x10\t\x12\x37\n3TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_PARAMETERS_STATE\x10\x0b\x12\x35\n1TOPOLOGY_MAPPING_CODE_MEDIATOR_SYNCHRONIZER_STATE\x10\x0c\x12\x36\n2TOPOLOGY_MAPPING_CODE_SEQUENCER_SYNCHRONIZER_STATE\x10\r\x12=\n9TOPOLOGY_MAPPING_CODE_SEQUENCING_DYNAMIC_PARAMETERS_STATE\x10\x11\x12.\n*TOPOLOGY_MAPPING_CODE_PARTY_TO_KEY_MAPPING\x10\x12\x12=\n9TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_MIGRATION_ANNOUNCEMENT\x10\x13\x12\x38\n4TOPOLOGY_MAPPING_CODE_SEQUENCER_CONNECTION_SUCCESSOR\x10\x14\"\x04\x08\x02\x10\x02\"\x04\x08\n\x10\n\"\x04\x08\x0e\x10\x0e\"\x04\x08\x0f\x10\x0f\"\x04\x08\x10\x10\x10\"\x90\x01\n\x16ParticipantFeatureFlag\x12(\n$PARTICIPANT_FEATURE_FLAG_UNSPECIFIED\x10\x00\x12L\nHPARTICIPANT_FEATURE_FLAG_PV33_EXTERNAL_SIGNING_LOCAL_CONTRACT_IN_SUBVIEW\x10\x01\"\xc4\x06\n\x13NamespaceDelegation\x12\x1c\n\tnamespace\x18\x01 \x01(\tR\tnamespace\x12S\n\ntarget_key\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\ttargetKey\x12\x30\n\x12is_root_delegation\x18\x03 \x01(\x08\x42\x02\x18\x01R\x10isRootDelegation\x12\x81\x01\n\x15\x63\x61n_sign_all_mappings\x18\x04 \x01(\x0b\x32L.com.digitalasset.canton.protocol.v30.NamespaceDelegation.CanSignAllMappingsH\x00R\x12\x63\x61nSignAllMappings\x12\xb0\x01\n&can_sign_all_but_namespace_delegations\x18\x05 \x01(\x0b\x32[.com.digitalasset.canton.protocol.v30.NamespaceDelegation.CanSignAllButNamespaceDelegationsH\x00R!canSignAllButNamespaceDelegations\x12\x8e\x01\n\x19\x63\x61n_sign_specific_mapings\x18\x06 \x01(\x0b\x32Q.com.digitalasset.canton.protocol.v30.NamespaceDelegation.CanSignSpecificMappingsH\x00R\x16\x63\x61nSignSpecificMapings\x1a\x14\n\x12\x43\x61nSignAllMappings\x1a#\n!CanSignAllButNamespaceDelegations\x1av\n\x17\x43\x61nSignSpecificMappings\x12[\n\x08mappings\x18\x01 \x03(\x0e\x32?.com.digitalasset.canton.protocol.v30.Enums.TopologyMappingCodeR\x08mappingsB\r\n\x0brestriction\"\x91\x01\n DecentralizedNamespaceDefinition\x12\x37\n\x17\x64\x65\x63\x65ntralized_namespace\x18\x01 \x01(\tR\x16\x64\x65\x63\x65ntralizedNamespace\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthreshold\x12\x16\n\x06owners\x18\x03 \x03(\tR\x06owners\"\x81\x01\n\x11OwnerToKeyMapping\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12N\n\x0bpublic_keys\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.PublicKeyR\npublicKeysJ\x04\x08\x03\x10\x04\"\xa6\x01\n\x11PartyToKeyMapping\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold\x12W\n\x0csigning_keys\x18\x04 \x03(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\x0bsigningKeysJ\x04\x08\x02\x10\x03\"\xe5\x01\n\x1cSynchronizerTrustCertificate\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12g\n\rfeature_flags\x18\x05 \x03(\x0e\x32\x42.com.digitalasset.canton.protocol.v30.Enums.ParticipantFeatureFlagR\x0c\x66\x65\x61tureFlagsJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xeb\x02\n!ParticipantSynchronizerPermission\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\'\n\x0fparticipant_uid\x18\x02 \x01(\tR\x0eparticipantUid\x12\x61\n\npermission\x18\x03 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\x12[\n\x06limits\x18\x04 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ParticipantSynchronizerLimitsR\x06limits\x12$\n\x0blogin_after\x18\x05 \x01(\x03H\x00R\nloginAfter\x88\x01\x01\x42\x0e\n\x0c_login_after\"Y\n\x12PartyHostingLimits\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x14\n\x05party\x18\x02 \x01(\tR\x05partyJ\x04\x08\x03\x10\x04\"\x93\x03\n\x0eVettedPackages\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12#\n\x0bpackage_ids\x18\x02 \x03(\tB\x02\x18\x01R\npackageIds\x12^\n\x08packages\x18\x04 \x03(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.VettedPackages.VettedPackageR\x08packages\x1a\xcc\x01\n\rVettedPackage\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12L\n\x14valid_from_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12validFromInclusive\x12N\n\x15valid_until_exclusive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validUntilExclusiveJ\x04\x08\x03\x10\x04\"\xf6\x04\n\x12PartyToParticipant\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12o\n\x0cparticipants\x18\x03 \x03(\x0b\x32K.com.digitalasset.canton.protocol.v30.PartyToParticipant.HostingParticipantR\x0cparticipants\x12o\n\x12party_signing_keys\x18\x06 \x01(\x0b\x32<.com.digitalasset.canton.crypto.v30.SigningKeysWithThresholdH\x00R\x10partySigningKeys\x88\x01\x01\x1a\xa6\x02\n\x12HostingParticipant\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x61\n\npermission\x18\x02 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\x12v\n\nonboarding\x18\x03 \x01(\x0b\x32V.com.digitalasset.canton.protocol.v30.PartyToParticipant.HostingParticipant.OnboardingR\nonboarding\x1a\x0c\n\nOnboardingB\x15\n\x13_party_signing_keysJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"\xc4\x01\n\x1bSynchronizerParametersState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12|\n\x17synchronizer_parameters\x18\x02 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.DynamicSynchronizerParametersR\x16synchronizerParameters\"\xc3\x01\n DynamicSequencingParametersState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12v\n\x15sequencing_parameters\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.DynamicSequencingParametersR\x14sequencingParameters\"\xae\x01\n\x19MediatorSynchronizerState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x14\n\x05group\x18\x02 \x01(\rR\x05group\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold\x12\x16\n\x06\x61\x63tive\x18\x04 \x03(\tR\x06\x61\x63tive\x12\x1c\n\tobservers\x18\x05 \x03(\tR\tobservers\"\x99\x01\n\x1aSequencerSynchronizerState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12\x16\n\x06\x61\x63tive\x18\x03 \x03(\tR\x06\x61\x63tive\x12\x1c\n\tobservers\x18\x04 \x03(\tR\tobservers\"\xad\x01\n\x1fSynchronizerUpgradeAnnouncement\x12K\n\"successor_physical_synchronizer_id\x18\x01 \x01(\tR\x1fsuccessorPhysicalSynchronizerId\x12=\n\x0cupgrade_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bupgradeTime\"\x86\x04\n\x1cSequencerConnectionSuccessor\x12!\n\x0csequencer_id\x18\x01 \x01(\tR\x0bsequencerId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12v\n\nconnection\x18\x03 \x01(\x0b\x32V.com.digitalasset.canton.protocol.v30.SequencerConnectionSuccessor.SequencerConnectionR\nconnection\x1a\xa1\x02\n\x13SequencerConnection\x12q\n\x04grpc\x18\x01 \x01(\x0b\x32[.com.digitalasset.canton.protocol.v30.SequencerConnectionSuccessor.SequencerConnection.GrpcH\x00R\x04grpc\x1a\x83\x01\n\x04Grpc\x12\x1c\n\tendpoints\x18\x01 \x03(\tR\tendpoints\x12?\n\x19\x63ustom_trust_certificates\x18\x02 \x01(\x0cH\x00R\x17\x63ustomTrustCertificates\x88\x01\x01\x42\x1c\n\x1a_custom_trust_certificatesB\x11\n\x0f\x63onnection_type\"\xae\x0f\n\x0fTopologyMapping\x12n\n\x14namespace_delegation\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.NamespaceDelegationH\x00R\x13namespaceDelegation\x12\x96\x01\n\"decentralized_namespace_definition\x18\x03 \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DecentralizedNamespaceDefinitionH\x00R decentralizedNamespaceDefinition\x12j\n\x14owner_to_key_mapping\x18\x04 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.OwnerToKeyMappingH\x00R\x11ownerToKeyMapping\x12\x8a\x01\n\x1esynchronizer_trust_certificate\x18\x05 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.SynchronizerTrustCertificateH\x00R\x1csynchronizerTrustCertificate\x12\x80\x01\n\x16participant_permission\x18\x06 \x01(\x0b\x32G.com.digitalasset.canton.protocol.v30.ParticipantSynchronizerPermissionH\x00R\x15participantPermission\x12l\n\x14party_hosting_limits\x18\x07 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyHostingLimitsH\x00R\x12partyHostingLimits\x12_\n\x0fvetted_packages\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.VettedPackagesH\x00R\x0evettedPackages\x12l\n\x14party_to_participant\x18\t \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyToParticipantH\x00R\x12partyToParticipant\x12\x87\x01\n\x1dsynchronizer_parameters_state\x18\x0b \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.SynchronizerParametersStateH\x00R\x1bsynchronizerParametersState\x12\x81\x01\n\x1bmediator_synchronizer_state\x18\x0c \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.MediatorSynchronizerStateH\x00R\x19mediatorSynchronizerState\x12\x84\x01\n\x1csequencer_synchronizer_state\x18\r \x01(\x0b\x32@.com.digitalasset.canton.protocol.v30.SequencerSynchronizerStateH\x00R\x1asequencerSynchronizerState\x12\x97\x01\n#sequencing_dynamic_parameters_state\x18\x0f \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DynamicSequencingParametersStateH\x00R sequencingDynamicParametersState\x12j\n\x14party_to_key_mapping\x18\x10 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.PartyToKeyMappingH\x00R\x11partyToKeyMapping\x12\x93\x01\n!synchronizer_upgrade_announcement\x18\x11 \x01(\x0b\x32\x45.com.digitalasset.canton.protocol.v30.SynchronizerUpgradeAnnouncementH\x00R\x1fsynchronizerUpgradeAnnouncement\x12\x8a\x01\n\x1esequencer_connection_successor\x18\x12 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.SequencerConnectionSuccessorH\x00R\x1csequencerConnectionSuccessorB\t\n\x07mappingJ\x04\x08\x02\x10\x03J\x04\x08\n\x10\x0bJ\x04\x08\x0e\x10\x0f\"\xda\x01\n\x13TopologyTransaction\x12Z\n\toperation\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mapping\"\x9a\x01\n\x1aMultiTransactionSignatures\x12-\n\x12transaction_hashes\x18\x01 \x03(\x0cR\x11transactionHashes\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"\xad\x02\n\x19SignedTopologyTransaction\x12 \n\x0btransaction\x18\x01 \x01(\x0cR\x0btransaction\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\x12\x1a\n\x08proposal\x18\x03 \x01(\x08R\x08proposal\x12\x82\x01\n\x1cmulti_transaction_signatures\x18\x04 \x03(\x0b\x32@.com.digitalasset.canton.protocol.v30.MultiTransactionSignaturesR\x1amultiTransactionSignatures\"K\n\x1aSignedTopologyTransactions\x12-\n\x12signed_transaction\x18\x01 \x03(\x0cR\x11signedTransaction\"\xcc\x01\n\x1dTopologyTransactionsBroadcast\x12\x38\n\x18physical_synchronizer_id\x18\x01 \x01(\tR\x16physicalSynchronizerId\x12q\n\x13signed_transactions\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionsR\x12signedTransactionsBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.topology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_NAMESPACEDELEGATION'].fields_by_name['is_root_delegation']._loaded_options = None
  _globals['_NAMESPACEDELEGATION'].fields_by_name['is_root_delegation']._serialized_options = b'\030\001'
  _globals['_VETTEDPACKAGES'].fields_by_name['package_ids']._loaded_options = None
  _globals['_VETTEDPACKAGES'].fields_by_name['package_ids']._serialized_options = b'\030\001'
  _globals['_ENUMS']._serialized_start=310
  _globals['_ENUMS']._serialized_end=1671
  _globals['_ENUMS_TOPOLOGYCHANGEOP']._serialized_start=319
  _globals['_ENUMS_TOPOLOGYCHANGEOP']._serialized_end=440
  _globals['_ENUMS_PARTICIPANTPERMISSION']._serialized_start=443
  _globals['_ENUMS_PARTICIPANTPERMISSION']._serialized_end=626
  _globals['_ENUMS_TOPOLOGYMAPPINGCODE']._serialized_start=629
  _globals['_ENUMS_TOPOLOGYMAPPINGCODE']._serialized_end=1524
  _globals['_ENUMS_PARTICIPANTFEATUREFLAG']._serialized_start=1527
  _globals['_ENUMS_PARTICIPANTFEATUREFLAG']._serialized_end=1671
  _globals['_NAMESPACEDELEGATION']._serialized_start=1674
  _globals['_NAMESPACEDELEGATION']._serialized_end=2510
  _globals['_NAMESPACEDELEGATION_CANSIGNALLMAPPINGS']._serialized_start=2318
  _globals['_NAMESPACEDELEGATION_CANSIGNALLMAPPINGS']._serialized_end=2338
  _globals['_NAMESPACEDELEGATION_CANSIGNALLBUTNAMESPACEDELEGATIONS']._serialized_start=2340
  _globals['_NAMESPACEDELEGATION_CANSIGNALLBUTNAMESPACEDELEGATIONS']._serialized_end=2375
  _globals['_NAMESPACEDELEGATION_CANSIGNSPECIFICMAPPINGS']._serialized_start=2377
  _globals['_NAMESPACEDELEGATION_CANSIGNSPECIFICMAPPINGS']._serialized_end=2495
  _globals['_DECENTRALIZEDNAMESPACEDEFINITION']._serialized_start=2513
  _globals['_DECENTRALIZEDNAMESPACEDEFINITION']._serialized_end=2658
  _globals['_OWNERTOKEYMAPPING']._serialized_start=2661
  _globals['_OWNERTOKEYMAPPING']._serialized_end=2790
  _globals['_PARTYTOKEYMAPPING']._serialized_start=2793
  _globals['_PARTYTOKEYMAPPING']._serialized_end=2959
  _globals['_SYNCHRONIZERTRUSTCERTIFICATE']._serialized_start=2962
  _globals['_SYNCHRONIZERTRUSTCERTIFICATE']._serialized_end=3191
  _globals['_PARTICIPANTSYNCHRONIZERPERMISSION']._serialized_start=3194
  _globals['_PARTICIPANTSYNCHRONIZERPERMISSION']._serialized_end=3557
  _globals['_PARTYHOSTINGLIMITS']._serialized_start=3559
  _globals['_PARTYHOSTINGLIMITS']._serialized_end=3648
  _globals['_VETTEDPACKAGES']._serialized_start=3651
  _globals['_VETTEDPACKAGES']._serialized_end=4054
  _globals['_VETTEDPACKAGES_VETTEDPACKAGE']._serialized_start=3844
  _globals['_VETTEDPACKAGES_VETTEDPACKAGE']._serialized_end=4048
  _globals['_PARTYTOPARTICIPANT']._serialized_start=4057
  _globals['_PARTYTOPARTICIPANT']._serialized_end=4687
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT']._serialized_start=4358
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT']._serialized_end=4652
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT_ONBOARDING']._serialized_start=4640
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT_ONBOARDING']._serialized_end=4652
  _globals['_SYNCHRONIZERPARAMETERSSTATE']._serialized_start=4690
  _globals['_SYNCHRONIZERPARAMETERSSTATE']._serialized_end=4886
  _globals['_DYNAMICSEQUENCINGPARAMETERSSTATE']._serialized_start=4889
  _globals['_DYNAMICSEQUENCINGPARAMETERSSTATE']._serialized_end=5084
  _globals['_MEDIATORSYNCHRONIZERSTATE']._serialized_start=5087
  _globals['_MEDIATORSYNCHRONIZERSTATE']._serialized_end=5261
  _globals['_SEQUENCERSYNCHRONIZERSTATE']._serialized_start=5264
  _globals['_SEQUENCERSYNCHRONIZERSTATE']._serialized_end=5417
  _globals['_SYNCHRONIZERUPGRADEANNOUNCEMENT']._serialized_start=5420
  _globals['_SYNCHRONIZERUPGRADEANNOUNCEMENT']._serialized_end=5593
  _globals['_SEQUENCERCONNECTIONSUCCESSOR']._serialized_start=5596
  _globals['_SEQUENCERCONNECTIONSUCCESSOR']._serialized_end=6114
  _globals['_SEQUENCERCONNECTIONSUCCESSOR_SEQUENCERCONNECTION']._serialized_start=5825
  _globals['_SEQUENCERCONNECTIONSUCCESSOR_SEQUENCERCONNECTION']._serialized_end=6114
  _globals['_SEQUENCERCONNECTIONSUCCESSOR_SEQUENCERCONNECTION_GRPC']._serialized_start=5964
  _globals['_SEQUENCERCONNECTIONSUCCESSOR_SEQUENCERCONNECTION_GRPC']._serialized_end=6095
  _globals['_TOPOLOGYMAPPING']._serialized_start=6117
  _globals['_TOPOLOGYMAPPING']._serialized_end=8083
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=8086
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=8304
  _globals['_MULTITRANSACTIONSIGNATURES']._serialized_start=8307
  _globals['_MULTITRANSACTIONSIGNATURES']._serialized_end=8461
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_start=8464
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_end=8765
  _globals['_SIGNEDTOPOLOGYTRANSACTIONS']._serialized_start=8767
  _globals['_SIGNEDTOPOLOGYTRANSACTIONS']._serialized_end=8842
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST']._serialized_start=8845
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST']._serialized_end=9049
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .submission_tracking_pb2 import CommandRejected, CompletionInfo, SubmissionTrackingData, TransactionSubmissionTrackingData
from .party_replication_pb2 import PartyReplicationSourceParticipantMessage, PartyReplicationTargetParticipantMessage

__all__ = [
    "CommandRejected",
    "CompletionInfo",
    "PartyReplicationSourceParticipantMessage",
    "PartyReplicationTargetParticipantMessage",
    "SubmissionTrackingData",
    "TransactionSubmissionTrackingData",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .interactive_submission_data_pb2 import Create, Exercise, Fetch, Node, Rollback

__all__ = [
    "Create",
    "Exercise",
    "Fetch",
    "Node",
    "Rollback",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import logging
from pathlib import Path

from . import codegen

repo_root = Path(__file__).parent.parent.parent

logger = logging.getLogger("_dazl")

__all__ = ["update"]


def update(proto_pack: Path) -> None:
    """
    Update the parts of the dazl codebase that are code-generated.
    """
    python_gen_dir = repo_root / "python" / "dazl" / "_gen"
    go_gen_dir = repo_root / "go" / "api"

    # now generate our various files
    codegen.python_files(from_=proto_pack, to=python_gen_dir)
    codegen.go_files(from_=proto_pack, to=go_gen_dir)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .event_query_service_pb2 import GetEventsByContractIdRequest, GetEventsByContractIdResponse, GetEventsByContractKeyRequest, GetEventsByContractKeyResponse

__all__ = [
    "EventQueryServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class EventQueryServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _EventQueryServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _EventQueryServiceAsyncStub: ...  # type: ignore
    def GetEventsByContractId(self, __1: GetEventsByContractIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetEventsByContractIdResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetEventsByContractIdResponse]: ...
    def GetEventsByContractKey(self, __1: GetEventsByContractKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetEventsByContractKeyResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetEventsByContractKeyResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _EventQueryServiceBlockingStub(EventQueryServiceStub):
    def GetEventsByContractId(self, __1: GetEventsByContractIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetEventsByContractIdResponse: ...
    def GetEventsByContractKey(self, __1: GetEventsByContractKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetEventsByContractKeyResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _EventQueryServiceAsyncStub(EventQueryServiceStub):
    def GetEventsByContractId(self, __1: GetEventsByContractIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetEventsByContractIdResponse]: ...  # type: ignore
    def GetEventsByContractKey(self, __1: GetEventsByContractKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetEventsByContractKeyResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.object_meta import ObjectMeta


T = TypeVar("T", bound="PartyDetails")


@_attrs_define
class PartyDetails:
    """
    Attributes:
        party (str): The stable unique identifier of a Daml party.
            Must be a valid PartyIdString (as described in ``value.proto``).
            Required
        is_local (bool): true if party is hosted by the participant and the party shares the same identity provider as
            the user issuing the request.
            Optional
        identity_provider_id (str): The id of the ``Identity Provider``
            Optional, if not set, there could be 3 options:

            1. the party is managed by the default identity provider.
            2. party is not hosted by the participant.
            3. party is hosted by the participant, but is outside of the user's identity provider.
        local_metadata (ObjectMeta | Unset): Represents metadata corresponding to a participant resource (e.g. a
            participant user or participant local information about a party).

            Based on ``ObjectMeta`` meta used in Kubernetes API.
            See https://github.com/kubernetes/apimachinery/blob/master/pkg/apis/meta/v1/generated.proto#L640
    """

    party: str
    is_local: bool
    identity_provider_id: str
    local_metadata: ObjectMeta | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        party = self.party

        is_local = self.is_local

        identity_provider_id = self.identity_provider_id

        local_metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.local_metadata, Unset):
            local_metadata = self.local_metadata.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "party": party,
                "isLocal": is_local,
                "identityProviderId": identity_provider_id,
            }
        )
        if local_metadata is not UNSET:
            field_dict["localMetadata"] = local_metadata

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.object_meta import ObjectMeta

        d = dict(src_dict)
        party = d.pop("party")

        is_local = d.pop("isLocal")

        identity_provider_id = d.pop("identityProviderId")

        _local_metadata = d.pop("localMetadata", UNSET)
        local_metadata: ObjectMeta | Unset
        if isinstance(_local_metadata, Unset):
            local_metadata = UNSET
        else:
            local_metadata = ObjectMeta.from_dict(_local_metadata)

        party_details = cls(
            party=party,
            is_local=is_local,
            identity_provider_id=identity_provider_id,
            local_metadata=local_metadata,
        )

        party_details.additional_properties = d
        return party_details

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GenerateExternalPartyTopologyResponse")


@_attrs_define
class GenerateExternalPartyTopologyResponse:
    """Response message with topology transactions and the multi-hash to be signed.

    Attributes:
        party_id (str): the generated party id
        public_key_fingerprint (str): the fingerprint of the supplied public key
        multi_hash (str): the multi-hash which may be signed instead of each individual transaction
        topology_transactions (list[str] | Unset): The serialized topology transactions which need to be signed and
            submitted as part of the allocate party process
            Note that the serialization includes the versioning information. Therefore, the transaction here is serialized
            as an `UntypedVersionedMessage` which in turn contains the serialized `TopologyTransaction` in the version
            supported by the synchronizer.
    """

    party_id: str
    public_key_fingerprint: str
    multi_hash: str
    topology_transactions: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        party_id = self.party_id

        public_key_fingerprint = self.public_key_fingerprint

        multi_hash = self.multi_hash

        topology_transactions: list[str] | Unset = UNSET
        if not isinstance(self.topology_transactions, Unset):
            topology_transactions = self.topology_transactions

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "partyId": party_id,
                "publicKeyFingerprint": public_key_fingerprint,
                "multiHash": multi_hash,
            }
        )
        if topology_transactions is not UNSET:
            field_dict["topologyTransactions"] = topology_transactions

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        party_id = d.pop("partyId")

        public_key_fingerprint = d.pop("publicKeyFingerprint")

        multi_hash = d.pop("multiHash")

        topology_transactions = cast(list[str], d.pop("topologyTransactions", UNSET))

        generate_external_party_topology_response = cls(
            party_id=party_id,
            public_key_fingerprint=public_key_fingerprint,
            multi_hash=multi_hash,
            topology_transactions=topology_transactions,
        )

        generate_external_party_topology_response.additional_properties = d
        return generate_external_party_topology_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.features_descriptor import FeaturesDescriptor


T = TypeVar("T", bound="GetLedgerApiVersionResponse")


@_attrs_define
class GetLedgerApiVersionResponse:
    """
    Attributes:
        version (str): The version of the ledger API.
        features (FeaturesDescriptor | Unset):
    """

    version: str
    features: FeaturesDescriptor | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        version = self.version

        features: dict[str, Any] | Unset = UNSET
        if not isinstance(self.features, Unset):
            features = self.features.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "version": version,
            }
        )
        if features is not UNSET:
            field_dict["features"] = features

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.features_descriptor import FeaturesDescriptor

        d = dict(src_dict)
        version = d.pop("version")

        _features = d.pop("features", UNSET)
        features: FeaturesDescriptor | Unset
        if isinstance(_features, Unset):
            features = UNSET
        else:
            features = FeaturesDescriptor.from_dict(_features)

        get_ledger_api_version_response = cls(
            version=version,
            features=features,
        )

        get_ledger_api_version_response.additional_properties = d
        return get_ledger_api_version_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/sequencing.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/sequencing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from ...v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5com/digitalasset/canton/protocol/v30/sequencing.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17google/rpc/status.proto\"\xfa\x01\n\x1dPossiblyIgnoredSequencedEvent\x12\x18\n\x07\x63ounter\x18\x01 \x01(\x03R\x07\x63ounter\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12N\n\rtrace_context\x18\x03 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContext\x12\x1d\n\nis_ignored\x18\x04 \x01(\x08R\tisIgnored\x12#\n\nunderlying\x18\x05 \x01(\x0cH\x00R\nunderlying\x88\x01\x01\x42\r\n\x0b_underlying\"\x82\x01\n\x0eRecipientsTree\x12\x1e\n\nrecipients\x18\x01 \x03(\tR\nrecipients\x12P\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.RecipientsTreeR\x08\x63hildren\"k\n\nRecipients\x12]\n\x0frecipients_tree\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.RecipientsTreeR\x0erecipientsTree\"A\n\x10ServiceAgreement\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nlegal_text\x18\x02 \x01(\tR\tlegalText\".\n\x18SequencingSubmissionCost\x12\x12\n\x04\x63ost\x18\x01 \x01(\x03R\x04\x63ost\"\xa8\x07\n\x1cStaticSynchronizerParameters\x12n\n\x16required_signing_specs\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.crypto.v30.RequiredSigningSpecsR\x14requiredSigningSpecs\x12w\n\x19required_encryption_specs\x18\x02 \x01(\x0b\x32;.com.digitalasset.canton.crypto.v30.RequiredEncryptionSpecsR\x17requiredEncryptionSpecs\x12{\n\x1erequired_symmetric_key_schemes\x18\x03 \x03(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x1brequiredSymmetricKeySchemes\x12k\n\x18required_hash_algorithms\x18\x04 \x03(\x0e\x32\x31.com.digitalasset.canton.crypto.v30.HashAlgorithmR\x16requiredHashAlgorithms\x12r\n\x1brequired_crypto_key_formats\x18\x05 \x03(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x18requiredCryptoKeyFormats\x12q\n\x1arequired_signature_formats\x18\x06 \x03(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.SignatureFormatR\x18requiredSignatureFormats\x12)\n\x10protocol_version\x18\x07 \x01(\x05R\x0fprotocolVersion\x12\x16\n\x06serial\x18\x08 \x01(\x05R\x06serial\x12<\n\x1a\x65nable_transparency_checks\x18\t \x01(\x08R\x18\x65nableTransparencyChecks\x12M\n\x15topology_change_delay\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationR\x13topologyChangeDelay\"\xc5\x01\n\x08\x45nvelope\x12\x18\n\x07\x63ontent\x18\x01 \x01(\x0cR\x07\x63ontent\x12P\n\nrecipients\x18\x02 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v30.RecipientsR\nrecipients\x12M\n\nsignatures\x18\x03 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"U\n\x05\x42\x61tch\x12L\n\tenvelopes\x18\x01 \x03(\x0b\x32..com.digitalasset.canton.protocol.v30.EnvelopeR\tenvelopes\"\x85\x02\n\x0f\x43ompressedBatch\x12h\n\talgorithm\x18\x01 \x01(\x0e\x32J.com.digitalasset.canton.protocol.v30.CompressedBatch.CompressionAlgorithmR\talgorithm\x12)\n\x10\x63ompressed_batch\x18\x02 \x01(\x0cR\x0f\x63ompressedBatch\"]\n\x14\x43ompressionAlgorithm\x12%\n!COMPRESSION_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43OMPRESSION_ALGORITHM_GZIP\x10\x01\"\xa9\x04\n\x0eSequencedEvent\x12\x32\n\x12previous_timestamp\x18\t \x01(\x03H\x00R\x11previousTimestamp\x88\x01\x01\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x38\n\x18physical_synchronizer_id\x18\x03 \x01(\tR\x16physicalSynchronizerId\x12\"\n\nmessage_id\x18\x04 \x01(\tH\x01R\tmessageId\x88\x01\x01\x12K\n\x05\x62\x61tch\x18\x05 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CompressedBatchR\x05\x62\x61tch\x12\x44\n\x14\x64\x65liver_error_reason\x18\x06 \x01(\x0b\x32\x12.google.rpc.StatusR\x12\x64\x65liverErrorReason\x12\x32\n\x12topology_timestamp\x18\x07 \x01(\x03H\x02R\x11topologyTimestamp\x88\x01\x01\x12]\n\x0ftraffic_receipt\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.TrafficReceiptR\x0etrafficReceiptB\x15\n\x13_previous_timestampB\r\n\x0b_message_idB\x15\n\x13_topology_timestampJ\x04\x08\x01\x10\x02\"\xdd\x03\n\x11SubmissionRequest\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1d\n\nmessage_id\x18\x02 \x01(\tR\tmessageId\x12K\n\x05\x62\x61tch\x18\x04 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CompressedBatchR\x05\x62\x61tch\x12.\n\x13max_sequencing_time\x18\x05 \x01(\x03R\x11maxSequencingTime\x12\x32\n\x12topology_timestamp\x18\x06 \x01(\x03H\x00R\x11topologyTimestamp\x88\x01\x01\x12`\n\x10\x61ggregation_rule\x18\x07 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.AggregationRuleR\x0f\x61ggregationRule\x12g\n\x0fsubmission_cost\x18\x08 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.SequencingSubmissionCostR\x0esubmissionCostB\x15\n\x13_topology_timestampBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.sequencing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_start=380
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_end=630
  _globals['_RECIPIENTSTREE']._serialized_start=633
  _globals['_RECIPIENTSTREE']._serialized_end=763
  _globals['_RECIPIENTS']._serialized_start=765
  _globals['_RECIPIENTS']._serialized_end=872
  _globals['_SERVICEAGREEMENT']._serialized_start=874
  _globals['_SERVICEAGREEMENT']._serialized_end=939
  _globals['_SEQUENCINGSUBMISSIONCOST']._serialized_start=941
  _globals['_SEQUENCINGSUBMISSIONCOST']._serialized_end=987
  _globals['_STATICSYNCHRONIZERPARAMETERS']._serialized_start=990
  _globals['_STATICSYNCHRONIZERPARAMETERS']._serialized_end=1926
  _globals['_ENVELOPE']._serialized_start=1929
  _globals['_ENVELOPE']._serialized_end=2126
  _globals['_BATCH']._serialized_start=2128
  _globals['_BATCH']._serialized_end=2213
  _globals['_COMPRESSEDBATCH']._serialized_start=2216
  _globals['_COMPRESSEDBATCH']._serialized_end=2477
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_start=2384
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_end=2477
  _globals['_SEQUENCEDEVENT']._serialized_start=2480
  _globals['_SEQUENCEDEVENT']._serialized_end=3033
  _globals['_SUBMISSIONREQUEST']._serialized_start=3036
  _globals['_SUBMISSIONREQUEST']._serialized_end=3513
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from .... import value_pb2 as _value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Fetch(_message.Message):
    __slots__ = ("lf_version", "contract_id", "package_name", "template_id", "signatories", "stakeholders", "acting_parties", "interface_id")
    LF_VERSION_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNATORIES_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    ACTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
    lf_version: str
    contract_id: str
    package_name: str
    template_id: _value_pb2.Identifier
    signatories: _containers.RepeatedScalarFieldContainer[str]
    stakeholders: _containers.RepeatedScalarFieldContainer[str]
    acting_parties: _containers.RepeatedScalarFieldContainer[str]
    interface_id: _value_pb2.Identifier
    def __init__(self, lf_version: _Optional[str] = ..., contract_id: _Optional[str] = ..., package_name: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., signatories: _Optional[_Iterable[str]] = ..., stakeholders: _Optional[_Iterable[str]] = ..., acting_parties: _Optional[_Iterable[str]] = ..., interface_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ...) -> None: ...

class Exercise(_message.Message):
    __slots__ = ("lf_version", "contract_id", "package_name", "template_id", "signatories", "stakeholders", "acting_parties", "interface_id", "choice_id", "chosen_value", "consuming", "children", "exercise_result", "choice_observers")
    LF_VERSION_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNATORIES_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    ACTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
    CHOICE_ID_FIELD_NUMBER: _ClassVar[int]
    CHOSEN_VALUE_FIELD_NUMBER: _ClassVar[int]
    CONSUMING_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_RESULT_FIELD_NUMBER: _ClassVar[int]
    CHOICE_OBSERVERS_FIELD_NUMBER: _ClassVar[int]
    lf_version: str
    contract_id: str
    package_name: str
    template_id: _value_pb2.Identifier
    signatories: _containers.RepeatedScalarFieldContainer[str]
    stakeholders: _containers.RepeatedScalarFieldContainer[str]
    acting_parties: _containers.RepeatedScalarFieldContainer[str]
    interface_id: _value_pb2.Identifier
    choice_id: str
    chosen_value: _value_pb2.Value
    consuming: bool
    children: _containers.RepeatedScalarFieldContainer[str]
    exercise_result: _value_pb2.Value
    choice_observers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, lf_version: _Optional[str] = ..., contract_id: _Optional[str] = ..., package_name: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., signatories: _Optional[_Iterable[str]] = ..., stakeholders: _Optional[_Iterable[str]] = ..., acting_parties: _Optional[_Iterable[str]] = ..., interface_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., choice_id: _Optional[str] = ..., chosen_value: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., consuming: bool = ..., children: _Optional[_Iterable[str]] = ..., exercise_result: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., choice_observers: _Optional[_Iterable[str]] = ...) -> None: ...

class Create(_message.Message):
    __slots__ = ("lf_version", "contract_id", "package_name", "template_id", "argument", "signatories", "stakeholders")
    LF_VERSION_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    SIGNATORIES_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    lf_version: str
    contract_id: str
    package_name: str
    template_id: _value_pb2.Identifier
    argument: _value_pb2.Value
    signatories: _containers.RepeatedScalarFieldContainer[str]
    stakeholders: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, lf_version: _Optional[str] = ..., contract_id: _Optional[str] = ..., package_name: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., argument: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., signatories: _Optional[_Iterable[str]] = ..., stakeholders: _Optional[_Iterable[str]] = ...) -> None: ...

class Rollback(_message.Message):
    __slots__ = ("children",)
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    children: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, children: _Optional[_Iterable[str]] = ...) -> None: ...

class Node(_message.Message):
    __slots__ = ("create", "fetch", "exercise", "rollback")
    CREATE_FIELD_NUMBER: _ClassVar[int]
    FETCH_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_FIELD_NUMBER: _ClassVar[int]
    ROLLBACK_FIELD_NUMBER: _ClassVar[int]
    create: Create
    fetch: Fetch
    exercise: Exercise
    rollback: Rollback
    def __init__(self, create: _Optional[_Union[Create, _Mapping]] = ..., fetch: _Optional[_Union[Fetch, _Mapping]] = ..., exercise: _Optional[_Union[Exercise, _Mapping]] = ..., rollback: _Optional[_Union[Rollback, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="Signature")


@_attrs_define
class Signature:
    """
    Attributes:
        format_ (str):
        signature (str):
        signed_by (str): The fingerprint/id of the keypair used to create this signature and needed to verify.
        signing_algorithm_spec (str): The signing algorithm specification used to produce this signature
    """

    format_: str
    signature: str
    signed_by: str
    signing_algorithm_spec: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        format_ = self.format_

        signature = self.signature

        signed_by = self.signed_by

        signing_algorithm_spec = self.signing_algorithm_spec

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "format": format_,
                "signature": signature,
                "signedBy": signed_by,
                "signingAlgorithmSpec": signing_algorithm_spec,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        format_ = d.pop("format")

        signature = d.pop("signature")

        signed_by = d.pop("signedBy")

        signing_algorithm_spec = d.pop("signingAlgorithmSpec")

        signature = cls(
            format_=format_,
            signature=signature,
            signed_by=signed_by,
            signing_algorithm_spec=signing_algorithm_spec,
        )

        signature.additional_properties = d
        return signature

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from ...crypto.v30 import crypto_pb2 as _crypto_pb2
from . import common_stable_pb2 as _common_stable_pb2
from . import merkle_pb2 as _merkle_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReassignmentId(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class UnassignmentCommonData(_message.Message):
    __slots__ = ("salt", "source_physical_synchronizer_id", "stakeholders", "reassigning_participant_uids", "uuid", "source_mediator_group", "submitter_metadata")
    SALT_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    REASSIGNING_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_MEDIATOR_GROUP_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_METADATA_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    source_physical_synchronizer_id: str
    stakeholders: _common_stable_pb2.Stakeholders
    reassigning_participant_uids: _containers.RepeatedScalarFieldContainer[str]
    uuid: str
    source_mediator_group: int
    submitter_metadata: ReassignmentSubmitterMetadata
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., source_physical_synchronizer_id: _Optional[str] = ..., stakeholders: _Optional[_Union[_common_stable_pb2.Stakeholders, _Mapping]] = ..., reassigning_participant_uids: _Optional[_Iterable[str]] = ..., uuid: _Optional[str] = ..., source_mediator_group: _Optional[int] = ..., submitter_metadata: _Optional[_Union[ReassignmentSubmitterMetadata, _Mapping]] = ...) -> None: ...

class ReassignmentViewTree(_message.Message):
    __slots__ = ("common_data", "participant_data")
    COMMON_DATA_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_DATA_FIELD_NUMBER: _ClassVar[int]
    common_data: bytes
    participant_data: _merkle_pb2.BlindableNode
    def __init__(self, common_data: _Optional[bytes] = ..., participant_data: _Optional[_Union[_merkle_pb2.BlindableNode, _Mapping]] = ...) -> None: ...

class AssignmentMediatorMessage(_message.Message):
    __slots__ = ("tree", "submitting_participant_signature")
    TREE_FIELD_NUMBER: _ClassVar[int]
    SUBMITTING_PARTICIPANT_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    tree: ReassignmentViewTree
    submitting_participant_signature: _crypto_pb2.Signature
    def __init__(self, tree: _Optional[_Union[ReassignmentViewTree, _Mapping]] = ..., submitting_participant_signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ...) -> None: ...

class UnassignmentMediatorMessage(_message.Message):
    __slots__ = ("tree", "submitting_participant_signature")
    TREE_FIELD_NUMBER: _ClassVar[int]
    SUBMITTING_PARTICIPANT_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    tree: ReassignmentViewTree
    submitting_participant_signature: _crypto_pb2.Signature
    def __init__(self, tree: _Optional[_Union[ReassignmentViewTree, _Mapping]] = ..., submitting_participant_signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ...) -> None: ...

class AssignmentCommonData(_message.Message):
    __slots__ = ("salt", "source_physical_synchronizer_id", "target_physical_synchronizer_id", "unassignment_ts", "stakeholders", "uuid", "target_mediator_group", "submitter_metadata", "reassigning_participant_uids")
    SALT_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    UNASSIGNMENT_TS_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    TARGET_MEDIATOR_GROUP_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_METADATA_FIELD_NUMBER: _ClassVar[int]
    REASSIGNING_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    source_physical_synchronizer_id: str
    target_physical_synchronizer_id: str
    unassignment_ts: _timestamp_pb2.Timestamp
    stakeholders: _common_stable_pb2.Stakeholders
    uuid: str
    target_mediator_group: int
    submitter_metadata: ReassignmentSubmitterMetadata
    reassigning_participant_uids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., source_physical_synchronizer_id: _Optional[str] = ..., target_physical_synchronizer_id: _Optional[str] = ..., unassignment_ts: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., stakeholders: _Optional[_Union[_common_stable_pb2.Stakeholders, _Mapping]] = ..., uuid: _Optional[str] = ..., target_mediator_group: _Optional[int] = ..., submitter_metadata: _Optional[_Union[ReassignmentSubmitterMetadata, _Mapping]] = ..., reassigning_participant_uids: _Optional[_Iterable[str]] = ...) -> None: ...

class ReassignmentSubmitterMetadata(_message.Message):
    __slots__ = ("submitter", "submitting_participant_uid", "command_id", "submission_id", "user_id", "workflow_id")
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    SUBMITTING_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    submitter: str
    submitting_participant_uid: str
    command_id: str
    submission_id: str
    user_id: str
    workflow_id: str
    def __init__(self, submitter: _Optional[str] = ..., submitting_participant_uid: _Optional[str] = ..., command_id: _Optional[str] = ..., submission_id: _Optional[str] = ..., user_id: _Optional[str] = ..., workflow_id: _Optional[str] = ...) -> None: ...

class UnassignmentView(_message.Message):
    __slots__ = ("salt", "target_physical_synchronizer_id", "target_timestamp", "contracts")
    SALT_FIELD_NUMBER: _ClassVar[int]
    TARGET_PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    target_physical_synchronizer_id: str
    target_timestamp: int
    contracts: _containers.RepeatedCompositeFieldContainer[ActiveContract]
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., target_physical_synchronizer_id: _Optional[str] = ..., target_timestamp: _Optional[int] = ..., contracts: _Optional[_Iterable[_Union[ActiveContract, _Mapping]]] = ...) -> None: ...

class UnassignmentData(_message.Message):
    __slots__ = ("submitter_metadata", "contracts", "reassigning_participant_uids", "source_physical_synchronizer_id", "target_physical_synchronizer_id", "target_timestamp", "unassignment_ts")
    SUBMITTER_METADATA_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    REASSIGNING_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    UNASSIGNMENT_TS_FIELD_NUMBER: _ClassVar[int]
    submitter_metadata: ReassignmentSubmitterMetadata
    contracts: _containers.RepeatedCompositeFieldContainer[ActiveContract]
    reassigning_participant_uids: _containers.RepeatedScalarFieldContainer[str]
    source_physical_synchronizer_id: str
    target_physical_synchronizer_id: str
    target_timestamp: _timestamp_pb2.Timestamp
    unassignment_ts: _timestamp_pb2.Timestamp
    def __init__(self, submitter_metadata: _Optional[_Union[ReassignmentSubmitterMetadata, _Mapping]] = ..., contracts: _Optional[_Iterable[_Union[ActiveContract, _Mapping]]] = ..., reassigning_participant_uids: _Optional[_Iterable[str]] = ..., source_physical_synchronizer_id: _Optional[str] = ..., target_physical_synchronizer_id: _Optional[str] = ..., target_timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., unassignment_ts: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AssignmentView(_message.Message):
    __slots__ = ("salt", "contracts", "reassignment_id")
    SALT_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_ID_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    contracts: _containers.RepeatedCompositeFieldContainer[ActiveContract]
    reassignment_id: ReassignmentId
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., contracts: _Optional[_Iterable[_Union[ActiveContract, _Mapping]]] = ..., reassignment_id: _Optional[_Union[ReassignmentId, _Mapping]] = ...) -> None: ...

class ActiveContract(_message.Message):
    __slots__ = ("contract", "reassignment_counter")
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_COUNTER_FIELD_NUMBER: _ClassVar[int]
    contract: bytes
    reassignment_counter: int
    def __init__(self, contract: _Optional[bytes] = ..., reassignment_counter: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.user import User


T = TypeVar("T", bound="GetUserResponse")


@_attrs_define
class GetUserResponse:
    """
    Attributes:
        user (User | Unset):  Users and rights
            /////////////////
             Users are used to dynamically manage the rights given to Daml applications.
             They are stored and managed per participant node.
    """

    user: User | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        user: dict[str, Any] | Unset = UNSET
        if not isinstance(self.user, Unset):
            user = self.user.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if user is not UNSET:
            field_dict["user"] = user

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.user import User

        d = dict(src_dict)
        _user = d.pop("user", UNSET)
        user: User | Unset
        if isinstance(_user, Unset):
            user = UNSET
        else:
            user = User.from_dict(_user)

        get_user_response = cls(
            user=user,
        )

        get_user_response.additional_properties = d
        return get_user_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import sequencer_service_pb2 as com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/digitalasset/canton/sequencer/api/v30/sequencer_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SequencerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendAsync = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/SendAsync',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
                _registered_method=True)
        self.Subscribe = channel.unary_stream(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/Subscribe',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionResponse.FromString,
                _registered_method=True)
        self.AcknowledgeSigned = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/AcknowledgeSigned',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedResponse.FromString,
                _registered_method=True)
        self.DownloadTopologyStateForInit = channel.unary_stream(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/DownloadTopologyStateForInit',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitResponse.FromString,
                _registered_method=True)
        self.DownloadTopologyStateForInitHash = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/DownloadTopologyStateForInitHash',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashResponse.FromString,
                _registered_method=True)
        self.GetTrafficStateForMember = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/GetTrafficStateForMember',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberResponse.FromString,
                _registered_method=True)
        self.GetTime = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/GetTime',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeResponse.FromString,
                _registered_method=True)


class SequencerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendAsync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcknowledgeSigned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadTopologyStateForInit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadTopologyStateForInitHash(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTrafficStateForMember(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SequencerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendAsync': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAsync,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncResponse.SerializeToString,
            ),
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionResponse.SerializeToString,
            ),
            'AcknowledgeSigned': grpc.unary_unary_rpc_method_handler(
                    servicer.AcknowledgeSigned,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedResponse.SerializeToString,
            ),
            'DownloadTopologyStateForInit': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadTopologyStateForInit,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitResponse.SerializeToString,
            ),
            'DownloadTopologyStateForInitHash': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadTopologyStateForInitHash,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashResponse.SerializeToString,
            ),
            'GetTrafficStateForMember': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTrafficStateForMember,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberResponse.SerializeToString,
            ),
            'GetTime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTime,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.sequencer.api.v30.SequencerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.sequencer.api.v30.SequencerService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SequencerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendAsync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/SendAsync',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/Subscribe',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcknowledgeSigned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/AcknowledgeSigned',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadTopologyStateForInit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/DownloadTopologyStateForInit',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadTopologyStateForInitHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/DownloadTopologyStateForInitHash',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTrafficStateForMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/GetTrafficStateForMember',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/GetTime',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .crypto_pb2 import AsymmetricEncrypted, CryptoKeyFormat, CryptoKeyPair, EncryptionAlgorithmSpec, EncryptionKeyPair, EncryptionKeyScheme, EncryptionKeySpec, EncryptionPrivateKey, EncryptionPublicKey, HashAlgorithm, Hmac, HmacAlgorithm, KeyPurpose, PasswordBasedEncrypted, PbkdfScheme, PrivateKey, PublicKey, PublicKeyWithName, RequiredEncryptionSpecs, RequiredSigningSpecs, Salt, Signature, SignatureDelegation, SignatureFormat, SigningAlgorithmSpec, SigningKeyPair, SigningKeyScheme, SigningKeySpec, SigningKeyUsage, SigningKeysWithThreshold, SigningPrivateKey, SigningPublicKey, SymmetricKey, SymmetricKeyScheme

__all__ = [
    "AsymmetricEncrypted",
    "CryptoKeyFormat",
    "CryptoKeyPair",
    "EncryptionAlgorithmSpec",
    "EncryptionKeyPair",
    "EncryptionKeyScheme",
    "EncryptionKeySpec",
    "EncryptionPrivateKey",
    "EncryptionPublicKey",
    "HashAlgorithm",
    "Hmac",
    "HmacAlgorithm",
    "KeyPurpose",
    "PasswordBasedEncrypted",
    "PbkdfScheme",
    "PrivateKey",
    "PublicKey",
    "PublicKeyWithName",
    "RequiredEncryptionSpecs",
    "RequiredSigningSpecs",
    "Salt",
    "Signature",
    "SignatureDelegation",
    "SignatureFormat",
    "SigningAlgorithmSpec",
    "SigningKeyPair",
    "SigningKeyScheme",
    "SigningKeySpec",
    "SigningKeyUsage",
    "SigningKeysWithThreshold",
    "SigningPrivateKey",
    "SigningPublicKey",
    "SymmetricKey",
    "SymmetricKeyScheme",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import offset_checkpoint_pb2 as _offset_checkpoint_pb2
from . import reassignment_pb2 as _reassignment_pb2
from . import topology_transaction_pb2 as _topology_transaction_pb2
from . import transaction_pb2 as _transaction_pb2
from . import transaction_filter_pb2 as _transaction_filter_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetUpdatesRequest(_message.Message):
    __slots__ = ("begin_exclusive", "end_inclusive", "update_format")
    BEGIN_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    END_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    UPDATE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    begin_exclusive: int
    end_inclusive: int
    update_format: _transaction_filter_pb2.UpdateFormat
    def __init__(self, begin_exclusive: _Optional[int] = ..., end_inclusive: _Optional[int] = ..., update_format: _Optional[_Union[_transaction_filter_pb2.UpdateFormat, _Mapping]] = ...) -> None: ...

class GetUpdatesResponse(_message.Message):
    __slots__ = ("transaction", "reassignment", "offset_checkpoint", "topology_transaction")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.Transaction
    reassignment: _reassignment_pb2.Reassignment
    offset_checkpoint: _offset_checkpoint_pb2.OffsetCheckpoint
    topology_transaction: _topology_transaction_pb2.TopologyTransaction
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.Transaction, _Mapping]] = ..., reassignment: _Optional[_Union[_reassignment_pb2.Reassignment, _Mapping]] = ..., offset_checkpoint: _Optional[_Union[_offset_checkpoint_pb2.OffsetCheckpoint, _Mapping]] = ..., topology_transaction: _Optional[_Union[_topology_transaction_pb2.TopologyTransaction, _Mapping]] = ...) -> None: ...

class GetUpdateByOffsetRequest(_message.Message):
    __slots__ = ("offset", "update_format")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    UPDATE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    offset: int
    update_format: _transaction_filter_pb2.UpdateFormat
    def __init__(self, offset: _Optional[int] = ..., update_format: _Optional[_Union[_transaction_filter_pb2.UpdateFormat, _Mapping]] = ...) -> None: ...

class GetUpdateByIdRequest(_message.Message):
    __slots__ = ("update_id", "update_format")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    update_format: _transaction_filter_pb2.UpdateFormat
    def __init__(self, update_id: _Optional[str] = ..., update_format: _Optional[_Union[_transaction_filter_pb2.UpdateFormat, _Mapping]] = ...) -> None: ...

class GetUpdateResponse(_message.Message):
    __slots__ = ("transaction", "reassignment", "topology_transaction")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.Transaction
    reassignment: _reassignment_pb2.Reassignment
    topology_transaction: _topology_transaction_pb2.TopologyTransaction
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.Transaction, _Mapping]] = ..., reassignment: _Optional[_Union[_reassignment_pb2.Reassignment, _Mapping]] = ..., topology_transaction: _Optional[_Union[_topology_transaction_pb2.TopologyTransaction, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="GetParticipantIdResponse")


@_attrs_define
class GetParticipantIdResponse:
    """
    Attributes:
        participant_id (str): Identifier of the participant, which SHOULD be globally unique.
            Must be a valid LedgerString (as describe in ``value.proto``).
    """

    participant_id: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        participant_id = self.participant_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "participantId": participant_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        participant_id = d.pop("participantId")

        get_participant_id_response = cls(
            participant_id=participant_id,
        )

        get_participant_id_response.additional_properties = d
        return get_participant_id_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/admin/package_management_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/admin/package_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import package_reference_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__reference__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/daml/ledger/api/v2/admin/package_management_service.proto\x12\x1c\x63om.daml.ledger.api.v2.admin\x1a.com/daml/ledger/api/v2/package_reference.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1a\n\x18ListKnownPackagesRequest\"r\n\x19ListKnownPackagesResponse\x12U\n\x0fpackage_details\x18\x01 \x03(\x0b\x32,.com.daml.ledger.api.v2.admin.PackageDetailsR\x0epackageDetails\"\xbd\x01\n\x0ePackageDetails\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12!\n\x0cpackage_size\x18\x02 \x01(\x04R\x0bpackageSize\x12;\n\x0bknown_since\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nknownSince\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12\x18\n\x07version\x18\x05 \x01(\tR\x07version\"\xe8\x02\n\x14UploadDarFileRequest\x12\x19\n\x08\x64\x61r_file\x18\x01 \x01(\x0cR\x07\x64\x61rFile\x12#\n\rsubmission_id\x18\x02 \x01(\tR\x0csubmissionId\x12g\n\x0evetting_change\x18\x03 \x01(\x0e\x32@.com.daml.ledger.api.v2.admin.UploadDarFileRequest.VettingChangeR\rvettingChange\x12\'\n\x0fsynchronizer_id\x18\x04 \x01(\tR\x0esynchronizerId\"~\n\rVettingChange\x12\x1e\n\x1aVETTING_CHANGE_UNSPECIFIED\x10\x00\x12#\n\x1fVETTING_CHANGE_VET_ALL_PACKAGES\x10\x01\x12(\n$VETTING_CHANGE_DONT_VET_ANY_PACKAGES\x10\x02\"\x17\n\x15UploadDarFileResponse\"\x81\x01\n\x16ValidateDarFileRequest\x12\x19\n\x08\x64\x61r_file\x18\x01 \x01(\x0cR\x07\x64\x61rFile\x12#\n\rsubmission_id\x18\x02 \x01(\tR\x0csubmissionId\x12\'\n\x0fsynchronizer_id\x18\x04 \x01(\tR\x0esynchronizerId\"\x19\n\x17ValidateDarFileResponse\"\x98\x04\n\x14VettedPackagesChange\x12J\n\x03vet\x18\x01 \x01(\x0b\x32\x36.com.daml.ledger.api.v2.admin.VettedPackagesChange.VetH\x00R\x03vet\x12P\n\x05unvet\x18\x02 \x01(\x0b\x32\x38.com.daml.ledger.api.v2.admin.VettedPackagesChange.UnvetH\x00R\x05unvet\x1aT\n\x05Unvet\x12K\n\x08packages\x18\x01 \x03(\x0b\x32/.com.daml.ledger.api.v2.admin.VettedPackagesRefR\x08packages\x1a\xfe\x01\n\x03Vet\x12K\n\x08packages\x18\x01 \x03(\x0b\x32/.com.daml.ledger.api.v2.admin.VettedPackagesRefR\x08packages\x12S\n\x18new_valid_from_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15newValidFromInclusive\x12U\n\x19new_valid_until_exclusive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x16newValidUntilExclusiveB\x0b\n\toperation\"~\n\x11VettedPackagesRef\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12\'\n\x0fpackage_version\x18\x03 \x01(\tR\x0epackageVersion\"\x9e\x03\n\x1bUpdateVettedPackagesRequest\x12L\n\x07\x63hanges\x18\x01 \x03(\x0b\x32\x32.com.daml.ledger.api.v2.admin.VettedPackagesChangeR\x07\x63hanges\x12\x17\n\x07\x64ry_run\x18\x02 \x01(\x08R\x06\x64ryRun\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12\x65\n\x18\x65xpected_topology_serial\x18\x04 \x01(\x0b\x32+.com.daml.ledger.api.v2.PriorTopologySerialR\x16\x65xpectedTopologySerial\x12\x87\x01\n\"update_vetted_packages_force_flags\x18\x05 \x03(\x0e\x32;.com.daml.ledger.api.v2.admin.UpdateVettedPackagesForceFlagR\x1eupdateVettedPackagesForceFlags\"\xd0\x01\n\x1cUpdateVettedPackagesResponse\x12X\n\x14past_vetted_packages\x18\x01 \x01(\x0b\x32&.com.daml.ledger.api.v2.VettedPackagesR\x12pastVettedPackages\x12V\n\x13new_vetted_packages\x18\x02 \x01(\x0b\x32&.com.daml.ledger.api.v2.VettedPackagesR\x11newVettedPackages*\xe2\x01\n\x1dUpdateVettedPackagesForceFlag\x12\x31\n-UPDATE_VETTED_PACKAGES_FORCE_FLAG_UNSPECIFIED\x10\x00\x12\x45\nAUPDATE_VETTED_PACKAGES_FORCE_FLAG_ALLOW_VET_INCOMPATIBLE_UPGRADES\x10\x02\x12\x41\n=UPDATE_VETTED_PACKAGES_FORCE_FLAG_ALLOW_UNVETTED_DEPENDENCIES\x10\x03\"\x04\x08\x01\x10\x01\x32\xab\x04\n\x18PackageManagementService\x12\x84\x01\n\x11ListKnownPackages\x12\x36.com.daml.ledger.api.v2.admin.ListKnownPackagesRequest\x1a\x37.com.daml.ledger.api.v2.admin.ListKnownPackagesResponse\x12x\n\rUploadDarFile\x12\x32.com.daml.ledger.api.v2.admin.UploadDarFileRequest\x1a\x33.com.daml.ledger.api.v2.admin.UploadDarFileResponse\x12~\n\x0fValidateDarFile\x12\x34.com.daml.ledger.api.v2.admin.ValidateDarFileRequest\x1a\x35.com.daml.ledger.api.v2.admin.ValidateDarFileResponse\x12\x8d\x01\n\x14UpdateVettedPackages\x12\x39.com.daml.ledger.api.v2.admin.UpdateVettedPackagesRequest\x1a:.com.daml.ledger.api.v2.admin.UpdateVettedPackagesResponseB\xae\x01\n\x1c\x63om.daml.ledger.api.v2.adminB\"PackageManagementServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V2.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.admin.package_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v2.adminB\"PackageManagementServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/admin\252\002\034Com.Daml.Ledger.Api.V2.Admin'
  _globals['_UPDATEVETTEDPACKAGESFORCEFLAG']._serialized_start=2355
  _globals['_UPDATEVETTEDPACKAGESFORCEFLAG']._serialized_end=2581
  _globals['_LISTKNOWNPACKAGESREQUEST']._serialized_start=176
  _globals['_LISTKNOWNPACKAGESREQUEST']._serialized_end=202
  _globals['_LISTKNOWNPACKAGESRESPONSE']._serialized_start=204
  _globals['_LISTKNOWNPACKAGESRESPONSE']._serialized_end=318
  _globals['_PACKAGEDETAILS']._serialized_start=321
  _globals['_PACKAGEDETAILS']._serialized_end=510
  _globals['_UPLOADDARFILEREQUEST']._serialized_start=513
  _globals['_UPLOADDARFILEREQUEST']._serialized_end=873
  _globals['_UPLOADDARFILEREQUEST_VETTINGCHANGE']._serialized_start=747
  _globals['_UPLOADDARFILEREQUEST_VETTINGCHANGE']._serialized_end=873
  _globals['_UPLOADDARFILERESPONSE']._serialized_start=875
  _globals['_UPLOADDARFILERESPONSE']._serialized_end=898
  _globals['_VALIDATEDARFILEREQUEST']._serialized_start=901
  _globals['_VALIDATEDARFILEREQUEST']._serialized_end=1030
  _globals['_VALIDATEDARFILERESPONSE']._serialized_start=1032
  _globals['_VALIDATEDARFILERESPONSE']._serialized_end=1057
  _globals['_VETTEDPACKAGESCHANGE']._serialized_start=1060
  _globals['_VETTEDPACKAGESCHANGE']._serialized_end=1596
  _globals['_VETTEDPACKAGESCHANGE_UNVET']._serialized_start=1242
  _globals['_VETTEDPACKAGESCHANGE_UNVET']._serialized_end=1326
  _globals['_VETTEDPACKAGESCHANGE_VET']._serialized_start=1329
  _globals['_VETTEDPACKAGESCHANGE_VET']._serialized_end=1583
  _globals['_VETTEDPACKAGESREF']._serialized_start=1598
  _globals['_VETTEDPACKAGESREF']._serialized_end=1724
  _globals['_UPDATEVETTEDPACKAGESREQUEST']._serialized_start=1727
  _globals['_UPDATEVETTEDPACKAGESREQUEST']._serialized_end=2141
  _globals['_UPDATEVETTEDPACKAGESRESPONSE']._serialized_start=2144
  _globals['_UPDATEVETTEDPACKAGESRESPONSE']._serialized_end=2352
  _globals['_PACKAGEMANAGEMENTSERVICE']._serialized_start=2584
  _globals['_PACKAGEMANAGEMENTSERVICE']._serialized_end=3139
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.js_contract_entry_type_0 import JsContractEntryType0
    from ..models.js_contract_entry_type_1 import JsContractEntryType1
    from ..models.js_contract_entry_type_2 import JsContractEntryType2
    from ..models.js_contract_entry_type_3 import JsContractEntryType3


T = TypeVar("T", bound="JsGetActiveContractsResponse")


@_attrs_define
class JsGetActiveContractsResponse:
    """
    Attributes:
        workflow_id (str): The workflow ID used in command submission which corresponds to the contract_entry. Only set
            if
            the ``workflow_id`` for the command was set.
            Must be a valid LedgerString (as described in ``value.proto``).
            Optional
        contract_entry (JsContractEntryType0 | JsContractEntryType1 | JsContractEntryType2 | JsContractEntryType3): For
            a contract there could be multiple contract_entry-s in the entire snapshot. These together define
            the state of one contract in the snapshot.
            A contract_entry is included in the result, if and only if there is at least one stakeholder party of the
            contract
            that is hosted on the synchronizer at the time of the event and the party satisfies the
            ``TransactionFilter`` in the query.
    """

    workflow_id: str
    contract_entry: (
        JsContractEntryType0
        | JsContractEntryType1
        | JsContractEntryType2
        | JsContractEntryType3
    )
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.js_contract_entry_type_0 import JsContractEntryType0
        from ..models.js_contract_entry_type_1 import JsContractEntryType1
        from ..models.js_contract_entry_type_2 import JsContractEntryType2

        workflow_id = self.workflow_id

        contract_entry: dict[str, Any]
        if isinstance(self.contract_entry, JsContractEntryType0):
            contract_entry = self.contract_entry.to_dict()
        elif isinstance(self.contract_entry, JsContractEntryType1):
            contract_entry = self.contract_entry.to_dict()
        elif isinstance(self.contract_entry, JsContractEntryType2):
            contract_entry = self.contract_entry.to_dict()
        else:
            contract_entry = self.contract_entry.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "workflowId": workflow_id,
                "contractEntry": contract_entry,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.js_contract_entry_type_0 import JsContractEntryType0
        from ..models.js_contract_entry_type_1 import JsContractEntryType1
        from ..models.js_contract_entry_type_2 import JsContractEntryType2
        from ..models.js_contract_entry_type_3 import JsContractEntryType3

        d = dict(src_dict)
        workflow_id = d.pop("workflowId")

        def _parse_contract_entry(
            data: object,
        ) -> (
            JsContractEntryType0
            | JsContractEntryType1
            | JsContractEntryType2
            | JsContractEntryType3
        ):
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_js_contract_entry_type_0 = (
                    JsContractEntryType0.from_dict(data)
                )

                return componentsschemas_js_contract_entry_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_js_contract_entry_type_1 = (
                    JsContractEntryType1.from_dict(data)
                )

                return componentsschemas_js_contract_entry_type_1
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_js_contract_entry_type_2 = (
                    JsContractEntryType2.from_dict(data)
                )

                return componentsschemas_js_contract_entry_type_2
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            if not isinstance(data, dict):
                raise TypeError()
            componentsschemas_js_contract_entry_type_3 = JsContractEntryType3.from_dict(
                data
            )

            return componentsschemas_js_contract_entry_type_3

        contract_entry = _parse_contract_entry(d.pop("contractEntry"))

        js_get_active_contracts_response = cls(
            workflow_id=workflow_id,
            contract_entry=contract_entry,
        )

        js_get_active_contracts_response.additional_properties = d
        return js_get_active_contracts_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PackageVettingRequirement")


@_attrs_define
class PackageVettingRequirement:
    """Defines a package-name for which the commonly vetted package with the highest version must be found.

    Attributes:
        package_name (str): The package-name for which the preferred package should be resolved.
            Required
        parties (list[str] | Unset): The parties whose participants' vetting state should be considered when resolving
            the preferred package.
            Required
    """

    package_name: str
    parties: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        package_name = self.package_name

        parties: list[str] | Unset = UNSET
        if not isinstance(self.parties, Unset):
            parties = self.parties

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "packageName": package_name,
            }
        )
        if parties is not UNSET:
            field_dict["parties"] = parties

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        package_name = d.pop("packageName")

        parties = cast(list[str], d.pop("parties", UNSET))

        package_vetting_requirement = cls(
            package_name=package_name,
            parties=parties,
        )

        package_vetting_requirement.additional_properties = d
        return package_vetting_requirement

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
